#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# __main__.py
# @Author : Gustavo Freitas (gustavo@gmf-tech.com)
# @Link   :

from logger_es_cli.cli_driver import app
import sys


def main():
    app(prog_name="logger-es-cli")


if __name__ == "__main__":
    sys.exit(main())



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# cli_driver.py
# @Author : Gustavo Freitas (gustavo@gmf-tech.com)
# @Link   :
# from logger_es_cli.dafaults import decorator_factory
from typing import Optional
import typer
from logger_es_cli import logger_factory, logger
import sys
import ujson as json

app = typer.Typer()


@app.command("configure")
def configure(type_config: str = "env"):
    """
    command to configure .env file
    """
    typer.echo(f"{type_config}")


@app.command("error")
def log_error(
    message: str,
    send_debug: bool = typer.Option(False, envvar="SEND_DEBUG"),
    exclude_default: bool = typer.Option(True, envvar="EXCLUDE_DEFAULT"),
    custom_file: Optional[typer.FileText] = typer.Option(None, envvar="CUSTOM_FILE"),
    kibana_ssl: bool = typer.Option(True, envvar="KIBANA_SSL"),
    exclude: str = typer.Option("", envvar="EXCLUDE"),
    save_filepath: str = typer.Option("/tmp", envvar="SAVE_FILEPATH"),
    save_file: bool = typer.Option(False, envvar="SAVE_FILE"),
    kibana_server: str = typer.Option("127.0.0.1", envvar="KIBANA_SERVER"),
    kibana_username: str = typer.Option("robots", envvar="KIBANA_USERNAME"),
    kibana_password: str = typer.Option("127456", envvar="KIBANA_PASSWORD"),
    kibana_server_port: int = typer.Option(443, envvar="KIBANA_SERVER_PORT"),
    environment: str = typer.Option("DEVELOPMENT", envvar="ENVIRONMENT"),
    project_name: str = typer.Option("test-index", envvar="PROJECT_NAME"),
):
    """
    send ERROR loglevel message
    """
    kibana_config = {
        "kibana_username": kibana_username,
        "kibana_server_port": kibana_server_port,
        "kibana_password": kibana_password,
        "kibana_server": kibana_server,
        "kibana_ssl": kibana_ssl,
    }

    extra_args = {}
    if custom_file:
        extra_args = json.loads(custom_file.read())

    logger_factory(
        funcname=sys._getframe().f_code.co_name,
        exclude_default=exclude_default,
        exclude=exclude,
        kibana_config=kibana_config,
        enable_file_log=save_file,
        path_log_file=save_filepath,
        environment=environment.upper(),
        project_name=project_name,
        send_debug=send_debug,
    )

    logger.error(message, extra=extra_args)

    typer.echo(
        f"send ERROR message to kibana:  [{message} {kibana_server}:{kibana_server_port}]!"
    )


@app.command("warning")
def log_warning(
    message: str,
    send_debug: bool = typer.Option(False, envvar="SEND_DEBUG"),
    exclude_default: bool = typer.Option(True, envvar="EXCLUDE_DEFAULT"),
    custom_file: Optional[typer.FileText] = typer.Option(None, envvar="CUSTOM_FILE"),
    kibana_ssl: bool = typer.Option(True, envvar="KIBANA_SSL"),
    exclude: str = typer.Option("", envvar="EXCLUDE"),
    save_filepath: str = typer.Option("/tmp", envvar="SAVE_FILEPATH"),
    save_file: bool = typer.Option(False, envvar="SAVE_FILE"),
    kibana_server: str = typer.Option("127.0.0.1", envvar="KIBANA_SERVER"),
    kibana_username: str = typer.Option("robots", envvar="KIBANA_USERNAME"),
    kibana_password: str = typer.Option("127456", envvar="KIBANA_PASSWORD"),
    kibana_server_port: int = typer.Option(443, envvar="KIBANA_SERVER_PORT"),
    environment: str = typer.Option("DEVELOPMENT", envvar="ENVIRONMENT"),
    project_name: str = typer.Option("test-index", envvar="PROJECT_NAME"),
):
    """
    send WARNING loglevel message
    """
    kibana_config = {
        "kibana_username": kibana_username,
        "kibana_server_port": kibana_server_port,
        "kibana_password": kibana_password,
        "kibana_server": kibana_server,
        "kibana_ssl": kibana_ssl,
    }

    extra_args = {}
    if custom_file:
        extra_args = json.loads(custom_file.read())

    logger_factory(
        funcname=sys._getframe().f_code.co_name,
        exclude_default=exclude_default,
        exclude=exclude,
        kibana_config=kibana_config,
        enable_file_log=save_file,
        path_log_file=save_filepath,
        environment=environment,
        project_name=project_name,
        send_debug=send_debug,
    )

    logger.warning(message, extra=extra_args)

    typer.echo(
        f"send WARNING message to kibana:  [{message} {kibana_server}:{kibana_server_port}]!"
    )


@app.command("debug")
def log_debug(
    message: str,
    send_debug: bool = typer.Option(False, envvar="SEND_DEBUG"),
    exclude_default: bool = typer.Option(True, envvar="EXCLUDE_DEFAULT"),
    custom_file: Optional[typer.FileText] = typer.Option(None, envvar="CUSTOM_FILE"),
    kibana_ssl: bool = typer.Option(True, envvar="KIBANA_SSL"),
    exclude: str = typer.Option("", envvar="EXCLUDE"),
    save_filepath: str = typer.Option("/tmp", envvar="SAVE_FILEPATH"),
    save_file: bool = typer.Option(False, envvar="SAVE_FILE"),
    kibana_server: str = typer.Option("127.0.0.1", envvar="KIBANA_SERVER"),
    kibana_username: str = typer.Option("robots", envvar="KIBANA_USERNAME"),
    kibana_password: str = typer.Option("127456", envvar="KIBANA_PASSWORD"),
    kibana_server_port: int = typer.Option(443, envvar="KIBANA_SERVER_PORT"),
    environment: str = typer.Option("DEVELOPMENT", envvar="ENVIRONMENT"),
    project_name: str = typer.Option("test-index", envvar="PROJECT_NAME"),
):
    """
    send DEBUG loglevel message
    """
    kibana_config = {
        "kibana_username": kibana_username,
        "kibana_server_port": kibana_server_port,
        "kibana_password": kibana_password,
        "kibana_server": kibana_server,
        "kibana_ssl": kibana_ssl,
    }

    extra_args = {}
    if custom_file:
        extra_args = json.loads(custom_file.read())

    logger_factory(
        funcname=sys._getframe().f_code.co_name,
        exclude_default=exclude_default,
        exclude=exclude,
        kibana_config=kibana_config,
        enable_file_log=save_file,
        path_log_file=save_filepath,
        environment=environment,
        project_name=project_name,
        send_debug=send_debug,
    )

    logger.debug(message, extra=extra_args)

    typer.echo(
        f"send DEBUG message to kibana:  [{message} {kibana_server}:{kibana_server_port}]!"
    )


@app.command("info")
def log_info(
    message: str,
    send_debug: bool = typer.Option(False, envvar="SEND_DEBUG"),
    exclude_default: bool = typer.Option(True, envvar="EXCLUDE_DEFAULT"),
    custom_file: Optional[typer.FileText] = typer.Option(None, envvar="CUSTOM_FILE"),
    kibana_ssl: bool = typer.Option(True, envvar="KIBANA_SSL"),
    exclude: str = typer.Option("", envvar="EXCLUDE"),
    save_filepath: str = typer.Option("/tmp", envvar="SAVE_FILEPATH"),
    save_file: bool = typer.Option(False, envvar="SAVE_FILE"),
    kibana_server: str = typer.Option("127.0.0.1", envvar="KIBANA_SERVER"),
    kibana_username: str = typer.Option("robots", envvar="KIBANA_USERNAME"),
    kibana_password: str = typer.Option("127456", envvar="KIBANA_PASSWORD"),
    kibana_server_port: int = typer.Option(443, envvar="KIBANA_SERVER_PORT"),
    environment: str = typer.Option("DEVELOPMENT", envvar="ENVIRONMENT"),
    project_name: str = typer.Option("test-index", envvar="PROJECT_NAME"),
):
    """
    send INFO loglevel message
    """
    kibana_config = {
        "kibana_username": kibana_username,
        "kibana_server_port": kibana_server_port,
        "kibana_password": kibana_password,
        "kibana_server": kibana_server,
        "kibana_ssl": kibana_ssl,
    }

    extra_args = {}
    if custom_file:
        extra_args = json.loads(custom_file.read())

    logger_factory(
        funcname=sys._getframe().f_code.co_name,
        exclude_default=exclude_default,
        exclude=exclude,
        kibana_config=kibana_config,
        enable_file_log=save_file,
        path_log_file=save_filepath,
        environment=environment,
        project_name=project_name,
        send_debug=send_debug,
    )

    logger.info(message, extra=extra_args)

    typer.echo(
        f"send INFO message to kibana:  [{message} {kibana_server}:{kibana_server_port}]!"
    )


@app.command("critical")
def log_critical(
    message: str,
    send_debug: bool = typer.Option(False, envvar="SEND_DEBUG"),
    exclude_default: bool = typer.Option(True, envvar="EXCLUDE_DEFAULT"),
    custom_file: Optional[typer.FileText] = typer.Option(None, envvar="CUSTOM_FILE"),
    kibana_ssl: bool = typer.Option(True, envvar="KIBANA_SSL"),
    exclude: str = typer.Option("", envvar="EXCLUDE"),
    save_filepath: str = typer.Option("/tmp", envvar="SAVE_FILEPATH"),
    save_file: bool = typer.Option(False, envvar="SAVE_FILE"),
    kibana_server: str = typer.Option("127.0.0.1", envvar="KIBANA_SERVER"),
    kibana_username: str = typer.Option("robots", envvar="KIBANA_USERNAME"),
    kibana_password: str = typer.Option("127456", envvar="KIBANA_PASSWORD"),
    kibana_server_port: int = typer.Option(443, envvar="KIBANA_SERVER_PORT"),
    environment: str = typer.Option("DEVELOPMENT", envvar="ENVIRONMENT"),
    project_name: str = typer.Option("test-index", envvar="PROJECT_NAME"),
):
    """
    send CRITICAL loglevel message
    """
    kibana_config = {
        "kibana_username": kibana_username,
        "kibana_server_port": kibana_server_port,
        "kibana_password": kibana_password,
        "kibana_server": kibana_server,
        "kibana_ssl": kibana_ssl,
    }

    extra_args = {}
    if custom_file:
        extra_args = json.loads(custom_file.read())

    logger_factory(
        funcname=sys._getframe().f_code.co_name,
        exclude_default=exclude_default,
        exclude=exclude,
        kibana_config=kibana_config,
        enable_file_log=save_file,
        path_log_file=save_filepath,
        environment=environment,
        project_name=project_name,
        send_debug=send_debug,
    )

    logger.critical(message, extra=extra_args)

    typer.echo(
        f"send CRITICAL message to kibana:  [{message} {kibana_server}:{kibana_server_port}]!"
    )


# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['logger_es_cli']

package_data = \
{'': ['*']}

install_requires = \
['elasticsearch>=7.13.1,<8.0.0',
 'logger-es-handler>=0.1.3,<0.2.0',
 'python-dotenv[cli]>=0.17.1,<0.18.0',
 'typer[all]>=0.3.2,<0.4.0',
 'ujson>=4.0.2,<5.0.0']

entry_points = \
{'console_scripts': ['logger-es-cli = logger_es_cli.cli_driver:app']}

setup_kwargs = {
    'name': 'logger-es-cli',
    'version': '0.3.4',
    'description': 'CLI for sending logging to elasticsearch',
    'long_description': '# logger-es-cli\n\nCLI for sending logging to elasticsearch (alpha version)\n\n## How to build package\n\n- needs to have poetry installed.\n\n  ```bash\n  sudo python3 -m pip install poetry\n  ```\n\n- optional\n\n  ```bash\n  sudo yum install redhat-rpm-config gcc libffi-devel python3-devel openssl-devel cargo\n  sudo python3 -m pip install python-dotenv[cli]\n  ```\n\n- run build command\n\n  ```bash\n  poetry build\n  ```\n\n## Access AWS ES with VPC access using a tunning ssh\n\n- open a terminal and issue the following command:\n\n  ```bash\n  ssh -L 9200:vpc-kibana-dashboard-maneiro-brbrhuehue.sa-east-1.es.amazonaws.com:443 -i ~/.ssh/your-private-key.pem ec2-user@5.6.7.8\n  ```\n\n- now try to send logs to elasticsearch\n\n## .env file env variables\n\nexample:\n\n```bash\n# kibana ip or dns\nKIBANA_SERVER=localhost\n# use SSL\nKIBANA_SSL=true\n# exclude default args from kibana\n# if true exclude those following args:\n# pathname,exc_info,exc_text,thread,threadName,stack_info,filename,processName,process,args,msg,name,levelname\nEXCLUDE_DEFAULT=true\n# kibana server port\nKIBANA_SERVER_PORT=9200\n# kibana username\nKIBANA_USERNAME=robots.logger\n# kibana password\nKIBANA_PASSWORD=fd89078C-2e8e-4549-b9de-B9955123a0e3\n# software environment\nENVIRONMENT=DEVELOPMENT\n# project name that is the same index name in elastic search\nPROJECT_NAME=gmf-tech-modulex\n# exclude args to send to elasticsearch\nEXCLUDE=thread,threadName,processName\n# a custom json file , to append when send logs to elasticsearch\nCUSTOM_FILE=/run/media/gustavo/backup/git-projects/logger-es-cli/custom.json\n# unbuffer sysout python\nPYTHONUNBUFFERED=true\n# send debug logs to es?\nSEND_DEBUG=false\n```\n\n## custom.json file\n\nexample:\n\n```json\n{\n  "username": "gustavo@gmf-tech.com",\n  "account": "system"\n}\n```\n\n## poetry export dependencies\n\n```bash\npoetry export -f requirements.txt --output requirements.txt\n```\n\n## run logger-es-cli with a .env file [dotenv dependence]\n\n```bash\ndotenv run -- logger-es-cli info \'alo mundo louco!!!\'\n```\n\n- Do not forget to issue command message with single quote. In bash if you send with double quotes, escape caracters will broken the CLI\n\n## License\n\nThis project is licensed under the terms of the MIT license.\n',
    'author': 'Gustavo Freitas',
    'author_email': 'gustavo@gmf-tech.com',
    'maintainer': 'Gustavo Freitas',
    'maintainer_email': 'gustavo@gmf-tech.com',
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)



__version__ = "0.1.0"

from logging import handlers
import socket
import logging
from logging.handlers import RotatingFileHandler
import os, sys
from logger_es_handler.handlers import ESHandler

handlers = set()


class MyFilter(logging.Filter):
    def __init__(self, param=None):
        self.param = param

    def filter(self, record):
        if self.param is None:
            allow = True
        else:
            allow = self.param not in record.msg
        if allow:
            record.level = record.levelname
            # delattr(record, 'levelname')
            record.host = socket.gethostname()
            record.hostIp = socket.gethostbyname(record.host)

        return allow


logger = logging.getLogger(__name__)
logger.addFilter(MyFilter())
logger.setLevel(logging.DEBUG)


def logger_factory(
    funcname,
    kibana_config,
    environment,
    project_name,
    exclude="",
    path_log_file="/tmp",
    enable_console_log=True,
    enable_file_log=False,
    enable_es_log=True,
    send_debug=False,
    exclude_default=True,
):

    if exclude:
        exclude = exclude.split(",")
    else:
        exclude = []
    if exclude_default:
        exclude += [
            "pathname",
            "exc_info",
            "exc_text",
            "thread",
            "threadName",
            "stack_info",
            "filename",
            "processName",
            "process",
            "args",
            "msg",
            "name",
            "levelname",
        ]

    exclude_tuple = tuple(set(exclude))

    if enable_file_log:

        if not os.path.exists(f"{path_log_file}"):
            os.makedirs(f"{path_log_file}")

        handler_local = RotatingFileHandler(
            f"{path_log_file}/{funcname}.log", mode="a", maxBytes=50000, backupCount=10
        )

        formatter = logging.Formatter(
            "[%(levelname)s] %(asctime)s %(funcName)s %(message)s"
        )

        handler_local.setLevel(logging.DEBUG)
        handler_local.setFormatter(formatter)

        handlers.add(handler_local)

    if enable_console_log:

        handler_console = logging.StreamHandler(sys.stdout)

        formatter = logging.Formatter(
            "[%(levelname)s] %(asctime)s [%(funcName)s:%(lineno)d] %(message)s"
        )

        handler_console.setLevel(logging.DEBUG)
        handler_console.setFormatter(formatter)

        handlers.add(handler_console)

    if enable_es_log:
        formatter = logging.Formatter(
            "[%(levelname)s] %(asctime)s %(funcName)s %(message)s"
        )
        handler_es = ESHandler(
            hosts=[
                {
                    "host": kibana_config["kibana_server"],
                    "port": kibana_config["kibana_server_port"],
                }
            ],
            auth_type=ESHandler.AuthType.BASIC_AUTH,
            auth_details=(
                kibana_config["kibana_username"],
                kibana_config["kibana_password"],
            ),
            use_ssl=kibana_config["kibana_ssl"],
            disabled_fields=exclude_tuple,
            verify_ssl=False if not environment == "PRODUCTION" else True,
            es_index_name=project_name,
            es_additional_fields={
                "project": project_name,
                "environment": environment,
            },
        )

        handler_es.setFormatter(formatter)
        if send_debug:
            handler_es.setLevel(logging.DEBUG)
        else:
            handler_es.setLevel(logging.INFO)
        handlers.add(handler_es)

    load_handlers()

    return logger


def load_handlers():
    for i_handler in handlers:
        if not i_handler in logger.handlers:
            logger.addHandler(i_handler)



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# dafaults.py
# @Author : Gustavo Freitas (gustavo@gmf-tech.com)
# @Link   :

# from pydantic import BaseModel, Field, validator
# import typer


from enum import Enum


class EnvironmentEnum(str, Enum):
    dev = "DEVELOPMENT"
    prd = "PRODUCTION"
    uat = "HOMOLOGATION"


# class CustomerBase(BaseModel):
#     kibana_server: str = typer.Argument("127.0.0.1", envvar="KIBANA_SERVER")


# def our_decorator(func):
#     """Decorator that inject default arguments"""

#     def wrap(*args, **kwargs):
#         result = func(*args, **kwargs)

#         print(func.__name__, "inject default env variables")
#         return result

#     return wrap

# def decorator_factory(argument):
#     def decorator(function):
#         def wrapper(*args, **kwargs):
#             #funny_stuff()
#             #something_with_argument(argument)
#             result = function(*args, **kwargs)
#             #more_funny_stuff()
#             return result
#         return wrapper
#     return decorator
